Getting started
===============

This section describes how to get started with Pindakaas.

Installation
------------

..  code-block:: bash

    $ pip install pindakaas

Basic example
-------------

.. literalinclude:: ../../examples/example.py
   :language: python

Further examples
----------------

Model and encode Boolean formulae and pseudo-Boolean constraints:

.. literalinclude:: ../../examples/example_modelling.py
   :language: python

Solve incrementally using assumptions:

.. literalinclude:: ../../examples/example_modelling.py
   :language: python
